@@ -37,6 +37,9 @@ class Device:
         else:
             return False
 
+    def is_partition_table(self):
+        return self._get_property('DeviceIsPartitionTable')
+
     def is_partition(self):
         return self._get_property('DeviceIsPartition')
 
@@ -58,6 +61,9 @@ class Device:
         if self.is_systeminternal():
             return False
 
+        if self.is_partition_table():
+            return False
+
         if self.is_opticaldisc():
             if self.is_hasmedia() and self.is_filesystem():
                 return True
